function C = designpid(G,omega,zeta,alpha,N)
% DESIGNPID  Designs a PID controller for the second-order continuous-time
%            LTI system G using pole placement.
%
%            C = DESIGNPID(G,omega,zeta,alpha);
%            C = DESIGNPID(G,omega,zeta,alpha,N);
%
%            The characteristic polynomial of the closed loop is
%            specified as (s^2+2*zeta*omega*s+omega^2)*(s+alpha*omega)
%
%            The optional argument N specifies the maximum gain in the
%            derivative part. The default value is N=10.

if ~isa(G,'lti')
  error('G must be an LTI system')
end
G = tf(G);

if ~issiso(G) || ~isct(G) || size(G,'order') ~= 2 || ~isproper(G)
  error('G must be a continuous-time second-order SISO system')
end

[B,A] = tfdata(G,'v');
if B(1)~= 0
  error('G must be strictly proper');
else
  B = B(2:3);
end

Acl = conv([1 2*zeta*omega omega^2],[1 alpha*omega]);
[R,S] = rstc(1,B,A,1,Acl,1,[1 0]);

if ~exist('N','var')
  N=10;
end

R = conv(R,[S(1)/S(2)/N 1]);

C = tf(S,R);
